@@ -11,4 +11,13 @@ pour l'utilisateur de la librairie
 """
 
 from NklTarget import *
+from NklResponse import *
+
+from nklAPI_Collections import *
+from nklAPI_Datas import *
+from nklAPI_Groups import *
+from nklAPI_Users import *
+from nklAPI_Vocabularies import *
+
+from nklUtils import *
 from nklPullCorpus import *
\ No newline at end of file
